<div align=right>
  <a href="https://pypi.org/project/monospace/"><img src="https://img.shields.io/pypi/v/monospace.svg?colorB=lightgrey" alt="PyPI" /></a>
  <a href="https://travis-ci.org/Tenchi2xh/monospace/"><img src="https://img.shields.io/travis/Tenchi2xh/monospace.svg" alt="Travis (.org)" /></a>
  <a href="https://www.codacy.com/app/Tenchi2xh/monospace"><img src="https://api.codacy.com/project/badge/Coverage/4c34d93852b246c0b2facdb93ff70fbe" alt="Coverage" /></a>
  <a href="https://www.codacy.com/app/Tenchi2xh/monospace"><img src="https://api.codacy.com/project/badge/Grade/4c34d93852b246c0b2facdb93ff70fbe" alt="Codacy grade" /></a>
</div>
<br/>

<pre>




                                ┌─────┬───┬───┬───┬───┬───┬───┬───┬───┐
                                │ ╷ ╷ │ · │ ╷ │ · ├   ┤ · │ · │   ┤   ╡
                                └─┴─┴─┴───┴─┴─┴───┴───┤ ┌─┴─┴─┴───┴───┘
                                                      └─┘
                                     <i>A fixed-width book typesetter</i>

                         Now re-implementing from scratch, powered by <a href="https://pandoc.org/">ᴘᴀɴᴅᴏᴄ</a>.





   ━━━━━━━━━━━━━━━━━━
      <b>About monospace</b>    While this readme is incomplete, you can read about the concept
                         for the project in the <a href="poc/README.md">ᴏʟᴅ ʀᴇᴀᴅᴍᴇ</a>. 
              <i>A short</i>    
         <i>introduction</i>    Or maybe you can get a preview of what is to come¹ with some
                         mockups of the current rendering target:
             ¹: Soon™
                         <img width="520" alt="page1" src="https://user-images.githubusercontent.com/4116708/44863793-64b15480-ac7e-11e8-9957-3f760c9b0e74.png">

                                       <i>Figure 1: first page of the mockup</i>


                         <img width="520" alt="page2" src="https://user-images.githubusercontent.com/4116708/44863794-64b15480-ac7e-11e8-91d3-36a17805270a.png">

                                      <i>Figure 2: second page of the mockup</i>


</pre>